/*----------------------------------------------------------------------------
           PalmSens EmStat Pico Development Board
  ----------------------------------------------------------------------------
  Copyright (c) 2018, PalmSens BV

  All rights reserved.

  You have a royalty-free right to use, modify, reproduce and distribute
  the Sample Application Files (and/or any modified version) in any way
  you find useful, provided that you agree that PalmSens B.V. has no
  warranty, obligations or liability for any Sample Application Files.


  Demonstrates use of the 32K I2C™ Serial EEPROM 'Microchip Technology Inc. 24AA32A/24LC32A
  (24XX32A*)' using the Arduino MKRZERO
  ----------------------------------------------------------------------------
*/

#include <Wire.h>


/********************************************************************************************************************************************************
  / Write one byte to the Eeprom
  /********************************************************************************************************************************************************/
void i2c_eeprom_write_byte( int deviceaddress, unsigned int eeaddress, byte data ) {
  int rdata = data;
  Wire.beginTransmission(deviceaddress);
  Wire.write((int)(eeaddress >> 8)); // MSB
  Wire.write((int)(eeaddress & 0xFF)); // LSB
  Wire.write(rdata);
  Wire.endTransmission();
  delay(100);
}


/********************************************************************************************************************************************************
  / Read one byte from the Eeprom
  /********************************************************************************************************************************************************/
byte i2c_eeprom_read_byte( int deviceaddress, unsigned int eeaddress ) {
  byte rdata = 0x00;
  Wire.beginTransmission(deviceaddress);
  Wire.write((int)(eeaddress >> 8)); // MSB
  Wire.write((int)(eeaddress & 0xFF)); // LSB
  Wire.endTransmission();
  delay(100);
  Wire.requestFrom(deviceaddress, 1);
  if (Wire.available()) rdata = Wire.read();
  return rdata;
}


/********************************************************************************************************************************************************
  / Setup the Serial communication and write "Hello Emstat Pico Dev" to the memory.
  / Program only proceeds when Serial is avalable. place next code in comment to auto-proceed.
  /
  / while (!Serial) {
  /   // wait for serial port to connect. Needed for native USB port only
  /  }
  /
/********************************************************************************************************************************************************/
void setup()
{
  Wire.begin(); // initialise the connection
  Serial.begin(9600);
  while (!Serial) {
    // wait for serial port to connect. Needed for native USB port only
  }
  Serial.println("Memory written");
  char myString[] = {"Hello Emstat Pico Dev"};
  for (int i = 0; i < 21; i++) {
    i2c_eeprom_write_byte(0x50, i, myString[i]); // write myString[i] to Eeprom Device address 0x50 and memory address i = {0,1,2, ... 20}
  }

  // Place any code here that only needs to be executed one time.

}


/********************************************************************************************************************************************************
/ Main Loop
/********************************************************************************************************************************************************/
void loop()
{
  byte rdata = 0;
  for (int i = 0; i < 21; i++) {
    rdata = i2c_eeprom_read_byte(0x50, i);  // Read from Eeprom Device address 0x50 and memory adress i = {0,1,2, ... 20}
    Serial.write((rdata));
  }
  Serial.println(" ");

  // Place any code here that needs to be executed infinitely.

}
