/*----------------------------------------------------------------------------
           PalmSens EmStat Pico Development Board
  ----------------------------------------------------------------------------
  Copyright (c) 2019, PalmSens BV

  All rights reserved.

  You have a royalty-free right to use, modify, reproduce and distribute
  the Sample Application Files (and/or any modified version) in any way
  you find useful, provided that you agree that PalmSens B.V. has no
  warranty, obligations or liability for any Sample Application Files.


  Demonstrates use of the Arduino MKR Series UART. 
  Connects the Bluetooth with the Emstat Pico Via the MKR. 
  UART : BT <-> MKR <-> PICO

  IMPORTANT : The Bluetooth and Emstat Pico need to be programmed with the default programmes!!
  Bluetooth Default File   : "$autorun$.SPP.UART.bridge.incoming.PicoDev"\
  Emstat Pico Default File : ""
  ----------------------------------------------------------------------------

  Open "ArduinoData\packages\arduino\hardware\samd\1.6.20\variants\mkrzero\variant.cpp"
  Delete or comment-out the following code (code is found at the end of the file).

      // Serial1
      Uart Serial1(&sercom5, PIN_SERIAL1_RX, PIN_SERIAL1_TX, PAD_SERIAL1_RX, PAD_SERIAL1_TX);

      void SERCOM5_Handler()
      {
        Serial1.IrqHandler();
      }

  Via the Bluetooth we can send a 't'  command to the MKR. The MKR forwards the 't' command to the pico, and sends back the information to the bluetooth.
  Also this a way to validate the connection between the MKR and the PICO, MKR to bluetooth.
  The Application used to send a 't' to the Bluetooth on the Pico Development board on ANDRIOD mobile device "Serial Bluetooth Terminal by Kai Morich"

*/

#include <Arduino.h>
#include "wiring_private.h"

Uart BT_Serial   (&sercom3,  1,  0, SERCOM_RX_PAD_1, UART_TX_PAD_0); // Create the new UART instance assigning it to pin 0 and 1
Uart Pico_Serial (&sercom5, 14, 13, SERCOM_RX_PAD_3, UART_TX_PAD_2); // Create the new UART instance assigning it to pin 0 and 1

// Attach the interrupt handler to the SERCOM
void SERCOM3_Handler(){
  BT_Serial.IrqHandler();
}

// Attach the interrupt handler to the SERCOM
void SERCOM5_Handler(){
  Pico_Serial.IrqHandler();
}

// PS-66
void setup() {
  // initialize serial communication :
  BT_Serial.begin(230400);
  Pico_Serial.begin(230400);
  Serial.begin(230400);
 
  // Assign pins 10 & 11 SERCOM functionality
  pinPeripheral(0, PIO_SERCOM);
  pinPeripheral(1, PIO_SERCOM);

  pinPeripheral(14, PIO_SERCOM_ALT);
  pinPeripheral(13, PIO_SERCOM_ALT);
}

// the loop routine runs over and over again forever:
void loop() {
  if (Pico_Serial.available())
  {
    char ReceiveByte_Pico = Pico_Serial.read();
    BT_Serial.write(ReceiveByte_Pico);
  }

  if (BT_Serial.available())
  {
    char ReceiveByte_BT = BT_Serial.read();
    Pico_Serial.write(ReceiveByte_BT);
  }

delay(20);
}
